==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/sl.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "An error occurred while generating your backup codes" : "Prišlo je do namako med ustvarjanjem varnostnih kok",
    "{name} backup codes" : "Varnostne kode {name}",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Varnostne kode je priporočljivo shraniti oziroma natisniti, saj jih v tej obliki prebrati ne bo več mogoče.",
    "Save backup codes" : "Shrani varnostne kode",
    "Print backup codes" : "Natisni varnostne kode",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Varnostne kode so bile uspešno ustvarjene. Uporabljeno {used} od skupno {total}.",
    "Regenerate backup codes" : "Osveži varnostne kode",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Z osvežitvijo varnostnih kod bo preklicana veljavnost starih.",
    "Generate backup codes" : "Ustvari rezervne šifre",
    "You created two-factor backup codes for your account" : "Za račun so uspešno ustvarjene dvo-stopenjske varnostne kode",
    "Second-factor backup codes" : "Varnostne kode druge stopnje",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Omogočena je dvostopenjska overitev, ni pa še ustvarjenih varnostnih kod. Prepričajte se, da so te ustvarjene za primer neveljavnosti kode druge stopnje.",
    "Backup code" : "Varnostna koda",
    "Use backup code" : "Uporabi varnostno kodo",
    "Two factor backup codes" : "Dvostopenjske varnostne kode",
    "A two-factor auth backup codes provider" : "Ponudnik varnostnih kod za dvostopenjsko overitev",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Uporabite eno izmed varnostnih kod, ki ste jo shranili pri nastavljanju dvostopenjske overitve",
    "Submit" : "Pošlji",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Varnostne kode so bile uspešno ustvarjene. Uporabljeno je {{used}} od skupno {{total}}.",
    "Nextcloud backup codes" : "Varnostne kode Nextcloud",
    "activated" : "omogočeno",
    "updated" : "posodobljeno",
    "mounted" : "priklopljeno",
    "deactivated" : "onemogočeno",
    "beforeCreate" : "pred ustvarjanjem",
    "created" : "ustvarjeno",
    "beforeUpdate" : "pred posodabljanjem",
    "beforeDestroy" : "pred uničenjem",
    "destroyed" : "uničeno",
    "beforeMount" : "pred priklapljanjem"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/sl.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "An error occurred while generating your backup codes" : "Prišlo je do namako med ustvarjanjem varnostnih kok",
    "{name} backup codes" : "Varnostne kode {name}",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Varnostne kode je priporočljivo shraniti oziroma natisniti, saj jih v tej obliki prebrati ne bo več mogoče.",
    "Save backup codes" : "Shrani varnostne kode",
    "Print backup codes" : "Natisni varnostne kode",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Varnostne kode so bile uspešno ustvarjene. Uporabljeno {used} od skupno {total}.",
    "Regenerate backup codes" : "Osveži varnostne kode",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Z osvežitvijo varnostnih kod bo preklicana veljavnost starih.",
    "Generate backup codes" : "Ustvari rezervne šifre",
    "You created two-factor backup codes for your account" : "Za račun so uspešno ustvarjene dvo-stopenjske varnostne kode",
    "Second-factor backup codes" : "Varnostne kode druge stopnje",
    "Backup code" : "Varnostna koda",
    "Use backup code" : "Uporabi varnostno kodo",
    "Two factor backup codes" : "Dvostopenjske varnostne kode",
    "A two-factor auth backup codes provider" : "Ponudnik varnostnih kod za dvostopenjsko overitev",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Uporabite eno izmed varnostnih kod, ki ste jo shranili pri nastavljanju dvostopenjske overitve",
    "Submit" : "Pošlji",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Varnostne kode so bile uspešno ustvarjene. Uporabljeno je {{used}} od skupno {{total}}.",
    "Nextcloud backup codes" : "Varnostne kode Nextcloud",
    "activated" : "omogočeno",
    "updated" : "posodobljeno",
    "mounted" : "priklopljeno",
    "deactivated" : "onemogočeno",
    "beforeCreate" : "pred ustvarjanjem",
    "created" : "ustvarjeno",
    "beforeUpdate" : "pred posodabljanjem",
    "beforeDestroy" : "pred uničenjem",
    "destroyed" : "uničeno",
    "beforeMount" : "pred priklapljanjem",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Omogočena je dvostopenjska overitev, ni pa še ustvarjenih varnostnih kod. Prepričajte se, da so te ustvarjene za primer neveljavnosti kode druge stopnje."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
